@@ -2,43 +2,46 @@ from .. import usbhid
 
 
 profile = {
-
     "name": "SteelSeries Sensei [RAW]",
-
-    "models": [{
-        "name": "SteelSeries Sensei [RAW]",
-        "vendor_id": 0x1038,
-        "product_id": 0x1369,
-        "endpoint": 0,
-    }, {
-        "name": "SteelSeries Sensei [RAW] Diablo III Edition",
-        "vendor_id": 0x1038,
-        "product_id": 0x1362,
-        "endpoint": 0,
-    }, {
-        "name": "SteelSeries Sensei [RAW] Guild Wars 2 Edition",
-        "vendor_id": 0x1038,
-        "product_id": 0x136d,
-        "endpoint": 0,
-    }, {
-        "name": "SteelSeries Sensei [RAW] CoD Black Ops II Edition",
-        "vendor_id": 0x1038,
-        "product_id": 0x136f,
-        "endpoint": 0,
-    }, {
-        "name": "SteelSeries Sensei [RAW] World of Tanks Edition",
-        "vendor_id": 0x1038,
-        "product_id": 0x1380,
-        "endpoint": 0,
-    }, {
-        "name": "SteelSeries Sensei [RAW] Heroes of the Storm Edition",
-        "vendor_id": 0x1038,
-        "product_id": 0x1390,
-        "endpoint": 0,
-    }],
-
+    "models": [
+        {
+            "name": "SteelSeries Sensei [RAW]",
+            "vendor_id": 0x1038,
+            "product_id": 0x1369,
+            "endpoint": 0,
+        },
+        {
+            "name": "SteelSeries Sensei [RAW] Diablo III Edition",
+            "vendor_id": 0x1038,
+            "product_id": 0x1362,
+            "endpoint": 0,
+        },
+        {
+            "name": "SteelSeries Sensei [RAW] Guild Wars 2 Edition",
+            "vendor_id": 0x1038,
+            "product_id": 0x136D,
+            "endpoint": 0,
+        },
+        {
+            "name": "SteelSeries Sensei [RAW] CoD Black Ops II Edition",
+            "vendor_id": 0x1038,
+            "product_id": 0x136F,
+            "endpoint": 0,
+        },
+        {
+            "name": "SteelSeries Sensei [RAW] World of Tanks Edition",
+            "vendor_id": 0x1038,
+            "product_id": 0x1380,
+            "endpoint": 0,
+        },
+        {
+            "name": "SteelSeries Sensei [RAW] Heroes of the Storm Edition",
+            "vendor_id": 0x1038,
+            "product_id": 0x1390,
+            "endpoint": 0,
+        },
+    ],
     "settings": {
-
         "sensitivity1": {
             "label": "Sensibility preset 1",
             "description": "Set sensitivity preset 1 (DPI)",
@@ -50,7 +53,6 @@ profile = {
             "output_range": [0x01, 0x3F, 1],
             "default": 1620,
         },
-
         "sensitivity2": {
             "label": "Sensitivity preset 2",
             "description": "Set sensitivity preset 2 (DPI)",
@@ -62,7 +64,6 @@ profile = {
             "output_range": [0x01, 0x3F, 1],
             "default": 3240,
         },
-
         "polling_rate": {
             "label": "Polling rate",
             "description": "Set polling rate (Hz)",
@@ -78,7 +79,6 @@ profile = {
             },
             "default": 1000,
         },
-
         "led_brightness": {
             "label": "LED Brightness",
             "description": "Set the brightness of the LEDs",
@@ -94,7 +94,6 @@ profile = {
             },
             "default": "off",
         },
-
         "light_effect": {
             "label": "Light effect",
             "description": "Set the light effect",
@@ -113,7 +112,6 @@ profile = {
             },
             "default": "breath",
         },
-
         "buttons_mapping": {
             "label": "Buttons mapping",
             "description": "Set the mapping of the buttons",
@@ -121,35 +119,30 @@ profile = {
             "report_type": usbhid.HID_REPORT_TYPE_OUTPUT,
             "command": [0x31, 0x00],
             "value_type": "buttons",
-
             "buttons": {
                 "Button1": {"id": 0x01, "offset": 0x00, "default": "button1"},
                 "Button2": {"id": 0x02, "offset": 0x03, "default": "button2"},
                 "Button3": {"id": 0x03, "offset": 0x06, "default": "button3"},
                 "Button4": {"id": 0x04, "offset": 0x09, "default": "button4"},
-                "Button5": {"id": 0x05, "offset": 0x0c, "default": "button5"},
+                "Button5": {"id": 0x05, "offset": 0x0C, "default": "button5"},
                 "Button6": {"id": 0x06, "offset": 0x12, "default": "PageDown"},
-                "Button7": {"id": 0x07, "offset": 0x0f, "default": "PageUp"},
+                "Button7": {"id": 0x07, "offset": 0x0F, "default": "PageUp"},
                 "Button8": {"id": 0x08, "offset": 0x15, "default": "dpi"},
             },
-
-            "button_field_length": 3,
-
+            # fmt: off
             "button_disable":     0x00,
             "button_keyboard":    0x10,
             "button_multimedia":  0x11,
             "button_dpi_switch":  0x30,
             "button_scroll_up":   None,
             "button_scroll_down": None,
-
-            "default": "buttons(button1=button1; button2=button2; button3=button3; button4=button4; button5=button5; button6=PageDown; button7=PageUp; button8=dpi; layout=qwerty)",  # noqa
+            # fmt: on
+            "button_field_length": 3,
+            "default": "buttons(button1=button1; button2=button2; button3=button3; button4=button4; button5=button5; button6=PageDown; button7=PageUp; button8=dpi; layout=qwerty)",
         },
-
     },
-
     "save_command": {
         "report_type": usbhid.HID_REPORT_TYPE_OUTPUT,
         "command": [0x09, 0x00],
     },
-
 }
