@@ -1,3 +1,4 @@
+import os
 import time
 
 from . import usbhid
@@ -39,7 +40,6 @@ def get_mouse(vendor_id=0x1038, product_id=None):
 
 
 class Mouse:
-
     """Generic class to handle any supported mouse.
 
     .. NOTE::
@@ -56,6 +56,8 @@ class Mouse:
                         :func:`rivalcfg.usbhid.open_device`).
     :param mouse_profile: One of the rivalcfg mouse profile (provided by
                             :func:`rivalcfg.devices.get_profile`).
+    :param float command_delay: Waiting time beween two commands to not
+                                overload the device.
 
     >>> from rivalcfg import usbhid
     >>> from rivalcfg import devices
@@ -77,11 +79,36 @@ class Mouse:
     #: The mouse settings (:class:`rivalcfg.mouse_settings.MouseSettings`)
     mouse_settings = None
 
-    def __init__(self, hid_device, mouse_profile, mouse_settings):
+    _MIN_COMMAND_DELAY = 0.001
+    _command_approve_delay = None
+
+    def __init__(self, hid_device, mouse_profile, mouse_settings, command_delay=0.05):
         """Constructor."""
         self._hid_device = hid_device
         self.mouse_profile = mouse_profile
         self.mouse_settings = mouse_settings
+        self.command_delay = command_delay
+
+    @property
+    def command_delay(self):
+        """Waiting time beween two commands to not overload the device.
+
+        .. WARNING::
+
+           Setting this value too low can hang the device. Some mice like the
+           Kinzu v2 are known to become laggy or even to crash when commands
+           are sent too quickly.
+        """
+        return self._command_delay
+
+    @command_delay.setter
+    def command_delay(self, new_value):
+        if new_value < self._MIN_COMMAND_DELAY:
+            raise ValueError(
+                f"command_delay is unsafe to use, with a delay of less than {self._MIN_COMMAND_DELAY} seconds"
+            )
+
+        self._command_approve_delay = new_value
 
     @property
     def name(self):
@@ -133,7 +160,7 @@ class Mouse:
 
         .. NOTE::
 
-           A value of ``None`` means the featue is not supported.
+           A value of ``None`` means the feature is not supported or that the mouse is turned off.
         """
         result = {
             "is_charging": None,
@@ -165,6 +192,9 @@ class Mouse:
         except Exception:
             pass
 
+        if result["level"] > 100 or result["level"] < 0:
+            return {"is_charging": None, "level": None}
+
         return result
 
     def reset_settings(self):
@@ -262,7 +292,8 @@ class Mouse:
             raise ValueError("Invalid HID report type: %2x" % report_type)
 
         # Avoids sending multiple commands to quickly
-        time.sleep(0.05)
+        if "RIVALCFG_DEBUG_NO_COMMAND_DELAY" not in os.environ:
+            time.sleep(self._command_approve_delay)
 
     def __getattr__(self, name):
         # Handle every set_xxx methods generated from device's profiles
